@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-import pypi_simple
+from pypi_simple import PyPISimple
 import sys
 
 from robin_sd_upload.supportive_scripts import logger
@@ -12,11 +12,18 @@ def check_latest_version():
     """Check if the latest version is installed and document how to update if needed."""
     config = yaml_parser.parse_config()
 
-    # package_name = config['static']['app_name']
-    package_name = "robin_sd_upload"
+    package_name = config['static']['app_name']
+    # print out package_name
+    print('package_name is: ' + package_name)
+    # package_name = "robin_sd_upload"
     current_version = _version.__version__
-    
-    latest_version = pypi_simple.package(package_name).version
+    pypi = PyPISimple()
+
+    # latest_version = pypi.get_latest_version(package_name)
+
+    page = pypi.get_project_page(package_name)
+    latest_version = page['info']['version']
+    print('latest_version is: ' + latest_version)
 
     if current_version == latest_version:
         logger.log(message="Latest version detected, proceeding.", log_level="info", to_file=True, to_terminal=False)
